Struct DynamicList
pub struct DynamicList { /* private fields */ }Expand description
A list of reflected values.
Implementations
impl DynamicList
impl DynamicList
pub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicList.
Panics
Panics if the given type is not a TypeInfo::List.
pub fn push<T>(&mut self, value: T)where
T: PartialReflect,
pub fn push<T>(&mut self, value: T)where
T: PartialReflect,
Appends a typed value to the list.
pub fn push_box(&mut self, value: Box<dyn PartialReflect>)
pub fn push_box(&mut self, value: Box<dyn PartialReflect>)
Appends a Reflect trait object to the list.