Struct TupleInfo
pub struct TupleInfo { /* private fields */ }Expand description
A container for compile-time tuple info.
Implementations
impl TupleInfo
impl TupleInfo
pub fn new<T>(fields: &[UnnamedField]) -> TupleInfo
pub fn new<T>(fields: &[UnnamedField]) -> TupleInfo
pub fn field_at(&self, index: usize) -> Option<&UnnamedField>
pub fn field_at(&self, index: usize) -> Option<&UnnamedField>
Get the field at the given index.
pub fn iter(&self) -> Iter<'_, UnnamedField>
pub fn iter(&self) -> Iter<'_, UnnamedField>
Iterate over the fields of this tuple.
pub fn type_path(&self) -> &'static str
pub fn type_path(&self) -> &'static str
The stable, full type path of this type.
Use type_path_table if you need access to the other methods on TypePath.
pub fn type_path_table(&self) -> &TypePathTable
pub fn type_path_table(&self) -> &TypePathTable
A representation of the type path of this type.
Provides dynamic access to all methods on TypePath.
pub fn with_generics(self, generics: Generics) -> TupleInfo
pub fn with_generics(self, generics: Generics) -> TupleInfo
Sets the generic parameters for this type.