RuntimeConfig

Struct RuntimeConfig 

pub struct RuntimeConfig {
    pub rate_target_hz: Option<u64>,
}

Fields

rate_target_hz: Option<u64>

Set a CopperList execution rate target in Hz It will act as a rate limiter: if the execution is slower than this rate, it will continue to execute at “best effort”.

The main usecase is to not waste cycles when the system doesn’t need an unbounded execution rate.