CuSingleOutputMsg

Trait CuSingleOutputMsg 

pub trait CuSingleOutputMsg {
    type Payload: CuMsgPayload;
}
Helper trait used by codegen when Copper needs to treat a task output as a single message slot without relying on config-declared output edges.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors