pub struct DistributedReplayAppRegistration {
pub subsystem: Subsystem,
pub app_type_name: &'static str,
/* private fields */
}Expand description
One typed subsystem registration provided to the distributed replay builder.
Fields
subsystem: Subsystemapp_type_name: &'static strTrait Implementations
Sourceimpl Clone for DistributedReplayAppRegistration
impl Clone for DistributedReplayAppRegistration
Sourcefn clone(&self) -> DistributedReplayAppRegistration
fn clone(&self) -> DistributedReplayAppRegistration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for DistributedReplayAppRegistration
impl PartialEq for DistributedReplayAppRegistration
Sourcefn eq(&self, other: &DistributedReplayAppRegistration) -> bool
fn eq(&self, other: &DistributedReplayAppRegistration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DistributedReplayAppRegistration