PayloadDefaultHandlePolicyApply

Trait PayloadDefaultHandlePolicyApply 

pub trait PayloadDefaultHandlePolicyApply {
    // Provided method
    fn apply_handle_content_policy(&self, _mode: HandleContent) { ... }
}
Default arm of the autoref-specialization pattern used by the runtime to push a source’s configured HandleContent policy into the CuHandles that live inside a payload. Default is a no-op; CuHandle and composite payloads provide inherent overrides that propagate the mode.

Provided Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors