pub trait CuApplication<S, L>where
S: SectionStorage,
L: UnifiedLogWrite<S> + 'static,{
// Required methods
fn get_original_config() -> String;
fn start_all_tasks(&mut self) -> Result<(), CuError>;
fn run_one_iteration(&mut self) -> Result<(), CuError>;
fn run(&mut self) -> Result<(), CuError>;
fn stop_all_tasks(&mut self) -> Result<(), CuError>;
fn restore_keyframe(&mut self, freezer: &KeyFrame) -> Result<(), CuError>;
}Expand description
A trait that defines the structure and behavior of a CuApplication.
CuApplication is the normal, running on robot version of an application and its runtime.
The CuApplication trait outlines the necessary functions required for managing an application lifecycle,
including configuration management, initialization, task execution, and runtime control. It is meant to be
implemented by types that represent specific applications, providing them with unified control and execution features.
This is the more generic version that allows you to specify a custom unified logger.
Required Methods
Sourcefn get_original_config() -> String
fn get_original_config() -> String
Returns the original configuration as a string, typically loaded from a RON file. This configuration represents the default settings for the application before any overrides.
Sourcefn start_all_tasks(&mut self) -> Result<(), CuError>
fn start_all_tasks(&mut self) -> Result<(), CuError>
Starts all tasks managed by the application/runtime.
Returns
Ok(())- If all tasks are started successfully.Err(CuResult)- If an error occurs while attempting to start one or more tasks.
Sourcefn run_one_iteration(&mut self) -> Result<(), CuError>
fn run_one_iteration(&mut self) -> Result<(), CuError>
Executes a single iteration of copper-generated runtime (generating and logging one copperlist)
Returns
CuResult<()>- ReturnsOk(())if the iteration completes successfully, or an error wrapped inCuResultif something goes wrong during execution.
Sourcefn run(&mut self) -> Result<(), CuError>
fn run(&mut self) -> Result<(), CuError>
Runs indefinitely looping over run_one_iteration
Returns
Returns a CuResult<()>, which indicates the success or failure of the
operation.
- On success, the result is
Ok(()). - On failure, an appropriate error wrapped in
CuResultis returned.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.