StructInfo

Struct StructInfo 

pub struct StructInfo { /* private fields */ }
A container for compile-time named struct info.

Implementations



impl StructInfo

pub fn new<T>(fields: &[NamedField]) -> StructInfo
where T: Reflect + TypePath,

Create a new StructInfo.

Arguments
  • fields: The fields of this struct in the order they are defined

pub fn with_custom_attributes( self, custom_attributes: CustomAttributes, ) -> StructInfo

Sets the custom attributes for this struct.

pub fn field_names(&self) -> &[&'static str]

A slice containing the names of all fields in order.

pub fn field(&self, name: &str) -> Option<&NamedField>

Get the field with the given name.

pub fn field_at(&self, index: usize) -> Option<&NamedField>

Get the field at the given index.

pub fn index_of(&self, name: &str) -> Option<usize>

Get the index of the field with the given name.

pub fn iter(&self) -> Iter<'_, NamedField>

Iterate over the fields of this struct.

pub fn field_len(&self) -> usize

The total number of fields in this struct.

pub fn ty(&self) -> &Type

The underlying Rust type.

pub fn type_id(&self) -> TypeId

The TypeId of this type.

pub fn type_path(&self) -> &'static str

The stable, full type path of this type.

Use type_path_table if you need access to the other methods on TypePath.

pub fn type_path_table(&self) -> &TypePathTable

A representation of the type path of this type.

Provides dynamic access to all methods on TypePath.

pub fn is<T>(&self) -> bool
where T: Any,

Check if the given type matches this one.

This only compares the TypeId of the types and does not verify they share the same TypePath (though it implies they do).

pub fn custom_attributes(&self) -> &CustomAttributes

Returns the custom attributes for this item.

pub fn get_attribute<T>(&self) -> Option<&T>
where T: Reflect,

Gets a custom attribute by type.

For dynamically accessing an attribute, see get_attribute_by_id.

pub fn get_attribute_by_id( &self, id: TypeId, ) -> Option<&(dyn Reflect + 'static)>

Gets a custom attribute by its TypeId.

This is the dynamic equivalent of get_attribute.

pub fn has_attribute<T>(&self) -> bool
where T: Reflect,

Returns true if this item has a custom attribute of the specified type.

For dynamically checking if an attribute exists, see has_attribute_by_id.

pub fn has_attribute_by_id(&self, id: TypeId) -> bool

Returns true if this item has a custom attribute with the specified TypeId.

This is the dynamic equivalent of has_attribute

pub fn generics(&self) -> &Generics

Gets the generic parameters for this type.

pub fn with_generics(self, generics: Generics) -> StructInfo

Sets the generic parameters for this type.