Struct UnnamedField
pub struct UnnamedField { /* private fields */ }Expand description
The unnamed field of a reflected tuple or tuple struct.
Implementations
impl UnnamedField
impl UnnamedField
pub fn new<T>(index: usize) -> UnnamedFieldwhere
T: PartialReflect + MaybeTyped + TypePath,
pub fn new<T>(index: usize) -> UnnamedFieldwhere
T: PartialReflect + MaybeTyped + TypePath,
Create a new UnnamedField.
pub fn with_custom_attributes(
self,
custom_attributes: CustomAttributes,
) -> UnnamedField
pub fn with_custom_attributes( self, custom_attributes: CustomAttributes, ) -> UnnamedField
Sets the custom attributes for this field.
pub fn type_info(&self) -> Option<&'static TypeInfo>
pub fn type_info(&self) -> Option<&'static TypeInfo>
The TypeInfo of the field.
Returns None if the field does not contain static type information,
such as for dynamic types.
pub fn type_path(&self) -> &'static str
pub fn type_path(&self) -> &'static str
The stable, full type path of this type.
Use type_path_table if you need access to the other methods on TypePath.
pub fn type_path_table(&self) -> &TypePathTable
pub fn type_path_table(&self) -> &TypePathTable
A representation of the type path of this type.
Provides dynamic access to all methods on TypePath.
pub fn custom_attributes(&self) -> &CustomAttributes
pub fn custom_attributes(&self) -> &CustomAttributes
Returns the custom attributes for this item.
pub fn get_attribute<T>(&self) -> Option<&T>where
T: Reflect,
pub fn get_attribute<T>(&self) -> Option<&T>where
T: Reflect,
Gets a custom attribute by type.
For dynamically accessing an attribute, see get_attribute_by_id.
pub fn get_attribute_by_id(
&self,
id: TypeId,
) -> Option<&(dyn Reflect + 'static)>
pub fn get_attribute_by_id( &self, id: TypeId, ) -> Option<&(dyn Reflect + 'static)>
Gets a custom attribute by its TypeId.
This is the dynamic equivalent of get_attribute.
pub fn has_attribute<T>(&self) -> boolwhere
T: Reflect,
pub fn has_attribute<T>(&self) -> boolwhere
T: Reflect,
Returns true if this item has a custom attribute of the specified type.
For dynamically checking if an attribute exists, see has_attribute_by_id.
pub fn has_attribute_by_id(&self, id: TypeId) -> bool
pub fn has_attribute_by_id(&self, id: TypeId) -> bool
Returns true if this item has a custom attribute with the specified TypeId.
This is the dynamic equivalent of has_attribute