GetTypeRegistration

Trait GetTypeRegistration 

pub trait GetTypeRegistration: 'static {
    // Required method
    fn get_type_registration() -> TypeRegistration;

    // Provided method
    fn register_type_dependencies(_registry: &mut TypeRegistry) { ... }
}
A trait which allows a type to generate its TypeRegistration for registration into the TypeRegistry.

This trait is automatically implemented for items using #[derive(Reflect)]. The macro also allows TypeData to be more easily registered.

If you need to use this trait as a generic bound along with other reflection traits, for your convenience, consider using Reflectable instead.

See the crate-level documentation for more information on type registration.

Required Methods

fn get_type_registration() -> TypeRegistration

Returns the default TypeRegistration for this type.

Provided Methods

fn register_type_dependencies(_registry: &mut TypeRegistry)

Registers other types needed by this type.

This method is called by TypeRegistry::register to register any other required types. Often, this is done for fields of structs and enum variants to ensure all types are properly registered.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl GetTypeRegistration for &'static str



impl GetTypeRegistration for &'static Location<'static>



impl GetTypeRegistration for Cow<'static, str>



impl GetTypeRegistration for SocketAddr



impl GetTypeRegistration for bool



impl GetTypeRegistration for char



impl GetTypeRegistration for f32



impl GetTypeRegistration for f64



impl GetTypeRegistration for i8



impl GetTypeRegistration for i16



impl GetTypeRegistration for i32



impl GetTypeRegistration for i64



impl GetTypeRegistration for i128



impl GetTypeRegistration for isize



impl GetTypeRegistration for u8



impl GetTypeRegistration for u16



impl GetTypeRegistration for u32



impl GetTypeRegistration for u64



impl GetTypeRegistration for u128



impl GetTypeRegistration for ()



impl GetTypeRegistration for usize

Source

impl GetTypeRegistration for Absement

Source

impl GetTypeRegistration for Acceleration

Source

impl GetTypeRegistration for Action

Source

impl GetTypeRegistration for AmountOfSubstance

Source

impl GetTypeRegistration for Angle

Source

impl GetTypeRegistration for AngularAbsement

Source

impl GetTypeRegistration for AngularAcceleration

Source

impl GetTypeRegistration for AngularJerk

Source

impl GetTypeRegistration for AngularMomentum

Source

impl GetTypeRegistration for AngularVelocity

Source

impl GetTypeRegistration for Area

Source

impl GetTypeRegistration for ArealDensityOfStates

Source

impl GetTypeRegistration for ArealHeatCapacity

Source

impl GetTypeRegistration for ArealMassDensity

Source

impl GetTypeRegistration for ArealNumberDensity

Source

impl GetTypeRegistration for ArealNumberRate

Source

impl GetTypeRegistration for AvailableEnergy

Source

impl GetTypeRegistration for Capacitance

Source

impl GetTypeRegistration for CatalyticActivity

Source

impl GetTypeRegistration for CatalyticActivityConcentration

Source

impl GetTypeRegistration for Curvature

Source

impl GetTypeRegistration for DiffusionCoefficient

Source

impl GetTypeRegistration for DynamicViscosity

Source

impl GetTypeRegistration for ElectricCharge

Source

impl GetTypeRegistration for ElectricChargeArealDensity

Source

impl GetTypeRegistration for ElectricChargeLinearDensity

Source

impl GetTypeRegistration for ElectricChargeVolumetricDensity

Source

impl GetTypeRegistration for ElectricCurrent

Source

impl GetTypeRegistration for ElectricCurrentDensity

Source

impl GetTypeRegistration for ElectricDipoleMoment

Source

impl GetTypeRegistration for ElectricDisplacementField

Source

impl GetTypeRegistration for ElectricField

Source

impl GetTypeRegistration for ElectricFlux

Source

impl GetTypeRegistration for ElectricPermittivity

Source

impl GetTypeRegistration for ElectricPotential

Source

impl GetTypeRegistration for ElectricQuadrupoleMoment

Source

impl GetTypeRegistration for ElectricalConductance

Source

impl GetTypeRegistration for ElectricalConductivity

Source

impl GetTypeRegistration for ElectricalMobility

Source

impl GetTypeRegistration for ElectricalResistance

Source

impl GetTypeRegistration for ElectricalResistivity

Source

impl GetTypeRegistration for Energy

Source

impl GetTypeRegistration for Force

Source

impl GetTypeRegistration for Frequency

Source

impl GetTypeRegistration for FrequencyDrift

Source

impl GetTypeRegistration for HeatCapacity

Source

impl GetTypeRegistration for HeatFluxDensity

Source

impl GetTypeRegistration for HeatTransfer

Source

impl GetTypeRegistration for Inductance

Source

impl GetTypeRegistration for Information

Source

impl GetTypeRegistration for InformationRate

Source

impl GetTypeRegistration for InverseVelocity

Source

impl GetTypeRegistration for Jerk

Source

impl GetTypeRegistration for KinematicViscosity

Source

impl GetTypeRegistration for Length

Source

impl GetTypeRegistration for LinearDensityOfStates

Source

impl GetTypeRegistration for LinearMassDensity

Source

impl GetTypeRegistration for LinearNumberDensity

Source

impl GetTypeRegistration for LinearNumberRate

Source

impl GetTypeRegistration for LinearPowerDensity

Source

impl GetTypeRegistration for Luminance

Source

impl GetTypeRegistration for LuminousIntensity

Source

impl GetTypeRegistration for MagneticFieldStrength

Source

impl GetTypeRegistration for MagneticFlux

Source

impl GetTypeRegistration for MagneticFluxDensity

Source

impl GetTypeRegistration for MagneticMoment

Source

impl GetTypeRegistration for MagneticPermeability

Source

impl GetTypeRegistration for Mass

Source

impl GetTypeRegistration for MassConcentration

Source

impl GetTypeRegistration for MassDensity

Source

impl GetTypeRegistration for MassFlux

Source

impl GetTypeRegistration for MassPerEnergy

Source

impl GetTypeRegistration for MassRate

Source

impl GetTypeRegistration for Molality

Source

impl GetTypeRegistration for MolarConcentration

Source

impl GetTypeRegistration for MolarEnergy

Source

impl GetTypeRegistration for MolarFlux

Source

impl GetTypeRegistration for MolarHeatCapacity

Source

impl GetTypeRegistration for MolarMass

Source

impl GetTypeRegistration for MolarRadioactivity

Source

impl GetTypeRegistration for MolarVolume

Source

impl GetTypeRegistration for MomentOfInertia

Source

impl GetTypeRegistration for Momentum

Source

impl GetTypeRegistration for Power

Source

impl GetTypeRegistration for PowerRate

Source

impl GetTypeRegistration for Pressure

Source

impl GetTypeRegistration for RadiantExposure

Source

impl GetTypeRegistration for Radioactivity

Source

impl GetTypeRegistration for Ratio

Source

impl GetTypeRegistration for ReciprocalLength

Source

impl GetTypeRegistration for SolidAngle

Source

impl GetTypeRegistration for SpecificArea

Source

impl GetTypeRegistration for SpecificHeatCapacity

Source

impl GetTypeRegistration for SpecificPower

Source

impl GetTypeRegistration for SpecificRadioactivity

Source

impl GetTypeRegistration for SpecificVolume

Source

impl GetTypeRegistration for SurfaceElectricCurrentDensity

Source

impl GetTypeRegistration for SurfaceTension

Source

impl GetTypeRegistration for TemperatureCoefficient

Source

impl GetTypeRegistration for TemperatureGradient

Source

impl GetTypeRegistration for TemperatureInterval

Source

impl GetTypeRegistration for ThermalConductance

Source

impl GetTypeRegistration for ThermalConductivity

Source

impl GetTypeRegistration for ThermalResistance

Source

impl GetTypeRegistration for ThermodynamicTemperature

Source

impl GetTypeRegistration for Time

Source

impl GetTypeRegistration for Torque

Source

impl GetTypeRegistration for Velocity

Source

impl GetTypeRegistration for Volume

Source

impl GetTypeRegistration for VolumeRate

Source

impl GetTypeRegistration for VolumetricDensityOfStates

Source

impl GetTypeRegistration for VolumetricHeatCapacity

Source

impl GetTypeRegistration for VolumetricNumberDensity

Source

impl GetTypeRegistration for VolumetricNumberRate

Source

impl GetTypeRegistration for VolumetricPowerDensity

Source

impl GetTypeRegistration for Absement

Source

impl GetTypeRegistration for Acceleration

Source

impl GetTypeRegistration for Action

Source

impl GetTypeRegistration for AmountOfSubstance

Source

impl GetTypeRegistration for Angle

Source

impl GetTypeRegistration for AngularAbsement

Source

impl GetTypeRegistration for AngularAcceleration

Source

impl GetTypeRegistration for AngularJerk

Source

impl GetTypeRegistration for AngularMomentum

Source

impl GetTypeRegistration for AngularVelocity

Source

impl GetTypeRegistration for Area

Source

impl GetTypeRegistration for ArealDensityOfStates

Source

impl GetTypeRegistration for ArealHeatCapacity

Source

impl GetTypeRegistration for ArealMassDensity

Source

impl GetTypeRegistration for ArealNumberDensity

Source

impl GetTypeRegistration for ArealNumberRate

Source

impl GetTypeRegistration for AvailableEnergy

Source

impl GetTypeRegistration for Capacitance

Source

impl GetTypeRegistration for CatalyticActivity

Source

impl GetTypeRegistration for CatalyticActivityConcentration

Source

impl GetTypeRegistration for Curvature

Source

impl GetTypeRegistration for DiffusionCoefficient

Source

impl GetTypeRegistration for DynamicViscosity

Source

impl GetTypeRegistration for ElectricCharge

Source

impl GetTypeRegistration for ElectricChargeArealDensity

Source

impl GetTypeRegistration for ElectricChargeLinearDensity

Source

impl GetTypeRegistration for ElectricChargeVolumetricDensity

Source

impl GetTypeRegistration for ElectricCurrent

Source

impl GetTypeRegistration for ElectricCurrentDensity

Source

impl GetTypeRegistration for ElectricDipoleMoment

Source

impl GetTypeRegistration for ElectricDisplacementField

Source

impl GetTypeRegistration for ElectricField

Source

impl GetTypeRegistration for ElectricFlux

Source

impl GetTypeRegistration for ElectricPermittivity

Source

impl GetTypeRegistration for ElectricPotential

Source

impl GetTypeRegistration for ElectricQuadrupoleMoment

Source

impl GetTypeRegistration for ElectricalConductance

Source

impl GetTypeRegistration for ElectricalConductivity

Source

impl GetTypeRegistration for ElectricalMobility

Source

impl GetTypeRegistration for ElectricalResistance

Source

impl GetTypeRegistration for ElectricalResistivity

Source

impl GetTypeRegistration for Energy

Source

impl GetTypeRegistration for Force

Source

impl GetTypeRegistration for Frequency

Source

impl GetTypeRegistration for FrequencyDrift

Source

impl GetTypeRegistration for HeatCapacity

Source

impl GetTypeRegistration for HeatFluxDensity

Source

impl GetTypeRegistration for HeatTransfer

Source

impl GetTypeRegistration for Inductance

Source

impl GetTypeRegistration for Information

Source

impl GetTypeRegistration for InformationRate

Source

impl GetTypeRegistration for InverseVelocity

Source

impl GetTypeRegistration for Jerk

Source

impl GetTypeRegistration for KinematicViscosity

Source

impl GetTypeRegistration for Length

Source

impl GetTypeRegistration for LinearDensityOfStates

Source

impl GetTypeRegistration for LinearMassDensity

Source

impl GetTypeRegistration for LinearNumberDensity

Source

impl GetTypeRegistration for LinearNumberRate

Source

impl GetTypeRegistration for LinearPowerDensity

Source

impl GetTypeRegistration for Luminance

Source

impl GetTypeRegistration for LuminousIntensity

Source

impl GetTypeRegistration for MagneticFieldStrength

Source

impl GetTypeRegistration for MagneticFlux

Source

impl GetTypeRegistration for MagneticFluxDensity

Source

impl GetTypeRegistration for MagneticMoment

Source

impl GetTypeRegistration for MagneticPermeability

Source

impl GetTypeRegistration for Mass

Source

impl GetTypeRegistration for MassConcentration

Source

impl GetTypeRegistration for MassDensity

Source

impl GetTypeRegistration for MassFlux

Source

impl GetTypeRegistration for MassPerEnergy

Source

impl GetTypeRegistration for MassRate

Source

impl GetTypeRegistration for Molality

Source

impl GetTypeRegistration for MolarConcentration

Source

impl GetTypeRegistration for MolarEnergy

Source

impl GetTypeRegistration for MolarFlux

Source

impl GetTypeRegistration for MolarHeatCapacity

Source

impl GetTypeRegistration for MolarMass

Source

impl GetTypeRegistration for MolarRadioactivity

Source

impl GetTypeRegistration for MolarVolume

Source

impl GetTypeRegistration for MomentOfInertia

Source

impl GetTypeRegistration for Momentum

Source

impl GetTypeRegistration for Power

Source

impl GetTypeRegistration for PowerRate

Source

impl GetTypeRegistration for Pressure

Source

impl GetTypeRegistration for RadiantExposure

Source

impl GetTypeRegistration for Radioactivity

Source

impl GetTypeRegistration for Ratio

Source

impl GetTypeRegistration for ReciprocalLength

Source

impl GetTypeRegistration for SolidAngle

Source

impl GetTypeRegistration for SpecificArea

Source

impl GetTypeRegistration for SpecificHeatCapacity

Source

impl GetTypeRegistration for SpecificPower

Source

impl GetTypeRegistration for SpecificRadioactivity

Source

impl GetTypeRegistration for SpecificVolume

Source

impl GetTypeRegistration for SurfaceElectricCurrentDensity

Source

impl GetTypeRegistration for SurfaceTension

Source

impl GetTypeRegistration for TemperatureCoefficient

Source

impl GetTypeRegistration for TemperatureGradient

Source

impl GetTypeRegistration for TemperatureInterval

Source

impl GetTypeRegistration for ThermalConductance

Source

impl GetTypeRegistration for ThermalConductivity

Source

impl GetTypeRegistration for ThermalResistance

Source

impl GetTypeRegistration for ThermodynamicTemperature

Source

impl GetTypeRegistration for Time

Source

impl GetTypeRegistration for Torque

Source

impl GetTypeRegistration for Velocity

Source

impl GetTypeRegistration for Volume

Source

impl GetTypeRegistration for VolumeRate

Source

impl GetTypeRegistration for VolumetricDensityOfStates

Source

impl GetTypeRegistration for VolumetricHeatCapacity

Source

impl GetTypeRegistration for VolumetricNumberDensity

Source

impl GetTypeRegistration for VolumetricNumberRate

Source

impl GetTypeRegistration for VolumetricPowerDensity



impl GetTypeRegistration for String



impl GetTypeRegistration for TypeId



impl GetTypeRegistration for NonZero<i8>



impl GetTypeRegistration for NonZero<i16>



impl GetTypeRegistration for NonZero<i32>



impl GetTypeRegistration for NonZero<i64>



impl GetTypeRegistration for NonZero<i128>



impl GetTypeRegistration for NonZero<isize>



impl GetTypeRegistration for NonZero<u8>



impl GetTypeRegistration for NonZero<u16>



impl GetTypeRegistration for NonZero<u32>



impl GetTypeRegistration for NonZero<u64>



impl GetTypeRegistration for NonZero<u128>



impl GetTypeRegistration for NonZero<usize>



impl GetTypeRegistration for RangeFull



impl GetTypeRegistration for Atomic<bool>



impl GetTypeRegistration for Atomic<i8>



impl GetTypeRegistration for Atomic<i16>



impl GetTypeRegistration for Atomic<i32>



impl GetTypeRegistration for Atomic<i64>



impl GetTypeRegistration for Atomic<isize>



impl GetTypeRegistration for Atomic<u8>



impl GetTypeRegistration for Atomic<u16>



impl GetTypeRegistration for Atomic<u32>



impl GetTypeRegistration for Atomic<u64>



impl GetTypeRegistration for Atomic<usize>



impl GetTypeRegistration for Duration



impl GetTypeRegistration for Instant



impl<A> GetTypeRegistration for (A,)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B> GetTypeRegistration for (A, B)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C> GetTypeRegistration for (A, B, C)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D> GetTypeRegistration for (A, B, C, D)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E> GetTypeRegistration for (A, B, C, D, E)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F> GetTypeRegistration for (A, B, C, D, E, F)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G> GetTypeRegistration for (A, B, C, D, E, F, G)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G, H> GetTypeRegistration for (A, B, C, D, E, F, G, H)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G, H, I> GetTypeRegistration for (A, B, C, D, E, F, G, H, I)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G, H, I, J> GetTypeRegistration for (A, B, C, D, E, F, G, H, I, J)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G, H, I, J, K> GetTypeRegistration for (A, B, C, D, E, F, G, H, I, J, K)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration, K: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<A, B, C, D, E, F, G, H, I, J, K, L> GetTypeRegistration for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration, K: Reflect + MaybeTyped + TypePath + GetTypeRegistration, L: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<K, V> GetTypeRegistration for BTreeMap<K, V>
where K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Ord, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<K, V, S> GetTypeRegistration for HashMap<K, V, S>



impl<T> GetTypeRegistration for Cow<'static, [T]>
where T: FromReflect + MaybeTyped + Clone + TypePath + GetTypeRegistration,



impl<T> GetTypeRegistration for Bound<T>
where T: Clone + Send + Sync + TypePath, Bound<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for Option<T>
where Option<T>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection,



impl<T> GetTypeRegistration for BinaryHeap<T>
where T: Clone + TypePath, BinaryHeap<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for BTreeSet<T>
where T: Ord + Eq + Clone + Send + Sync + TypePath, BTreeSet<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for VecDeque<T>
where T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<T> GetTypeRegistration for Arc<T>
where T: Send + Sync + TypePath + ?Sized, Arc<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for Vec<T>
where T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<T> GetTypeRegistration for Saturating<T>
where T: Clone + Send + Sync + TypePath, Saturating<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for Wrapping<T>
where T: Clone + Send + Sync + TypePath, Wrapping<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for Range<T>
where T: Clone + Send + Sync + TypePath, Range<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for RangeFrom<T>
where T: Clone + Send + Sync + TypePath, RangeFrom<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for RangeInclusive<T>
where T: Clone + Send + Sync + TypePath, RangeInclusive<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for RangeTo<T>
where T: Clone + Send + Sync + TypePath, RangeTo<T>: Any + Send + Sync,



impl<T> GetTypeRegistration for RangeToInclusive<T>
where T: Clone + Send + Sync + TypePath, RangeToInclusive<T>: Any + Send + Sync,



impl<T, E> GetTypeRegistration for Result<T, E>
where Result<T, E>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection, E: TypePath + FromReflect + MaybeTyped + RegisterForReflection,



impl<T, const N: usize> GetTypeRegistration for [T; N]
where T: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



impl<V, S> GetTypeRegistration for HashSet<V, S>

Implementors

Source

impl GetTypeRegistration for Tov

Source

impl GetTypeRegistration for CuMsgOrigin

Source

impl GetTypeRegistration for CuDuration

Source

impl GetTypeRegistration for CuMsgMetadata

Source

impl GetTypeRegistration for CuTime

Source

impl GetTypeRegistration for CuTimeRange

Source

impl GetTypeRegistration for OptionCuTime

Source

impl GetTypeRegistration for PartialCuTimeRange

Source

impl<I> GetTypeRegistration for CuSimSinkTask<I>
where CuSimSinkTask<I>: Any + Send + Sync,

Source

impl<T> GetTypeRegistration for CuLatchedState<T>
where T: Clone + TypePath, CuLatchedState<T>: Any + Send + Sync,

Source

impl<T> GetTypeRegistration for CuLatchedStateUpdate<T>

Source

impl<T> GetTypeRegistration for CuSimSrcTask<T>
where CuSimSrcTask<T>: Any + Send + Sync,

Source

impl<T, M> GetTypeRegistration for CuStampedData<T, M>

Source

impl<T, O> GetTypeRegistration for CuAsyncSrcTask<T, O>
where CuAsyncSrcTask<T, O>: Any + Send + Sync, T: for<'m> CuSrcTask<Output<'m> = CuStampedData<O, CuMsgMetadata>> + Send + 'static, O: CuMsgPayload + Send + 'static,

Source

impl<T, O> GetTypeRegistration for CuAsyncTask<T, O>
where CuAsyncTask<T, O>: Any + Send + Sync, T: for<'m> CuTask<Output<'m> = CuStampedData<O, CuMsgMetadata>> + Send + 'static, O: CuMsgPayload + Send + 'static,

Source

impl<T, const N: usize> GetTypeRegistration for CuArray<T, N>
where T: Clone + TypePath, CuArray<T, N>: Any + Send + Sync,

Source

impl<Tx, Rx> GetTypeRegistration for CuSimBridge<Tx, Rx>
where Tx: BridgeChannelSet + 'static, Rx: BridgeChannelSet + 'static, CuSimBridge<Tx, Rx>: Any + Send + Sync,