pub fn rate_target_period(rate_target_hz: u64) -> Result<CuDuration, CuError>Expand description
Convert a configured runtime rate target to an integer-nanosecond period.
pub fn rate_target_period(rate_target_hz: u64) -> Result<CuDuration, CuError>Convert a configured runtime rate target to an integer-nanosecond period.