pub struct CuExecutionLoop {
pub steps: Vec<CuExecutionUnit>,
pub loop_count: Option<u32>,
}Expand description
This structure represents a loop in the execution plan. It is used to represent a sequence of Execution units (loop or steps) that are executed multiple times. if loop_count is None, the loop is infinite.
Fields
steps: Vec<CuExecutionUnit>loop_count: Option<u32>Trait Implementations