pub struct KeyFrame {
pub culistid: u64,
pub timestamp: CuDuration,
pub serialized_tasks: Vec<u8>,
}Expand description
A KeyFrame is recording a snapshot of the tasks state before a given copperlist. It is a double encapsulation: this one recording the culistid and another even in bincode in the serialized_tasks.
Fields
culistid: u64timestamp: CuDurationserialized_tasks: Vec<u8>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for KeyFrame
impl<'__de, __Context> BorrowDecode<'__de, __Context> for KeyFrame
Sourcefn borrow_decode<__D>(decoder: &mut __D) -> Result<KeyFrame, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(decoder: &mut __D) -> Result<KeyFrame, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.