pub struct RuntimeLifecycleStackInfo {
pub app_name: String,
pub app_version: String,
pub git_commit: Option<String>,
pub git_dirty: Option<bool>,
}Expand description
Build-time stack identification metadata.
Fields
app_name: Stringapp_version: Stringgit_commit: Option<String>git_dirty: Option<bool>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for RuntimeLifecycleStackInfo
impl<'__de, __Context> BorrowDecode<'__de, __Context> for RuntimeLifecycleStackInfo
Sourcefn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<RuntimeLifecycleStackInfo, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(
decoder: &mut __D,
) -> Result<RuntimeLifecycleStackInfo, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for RuntimeLifecycleStackInfo
impl Clone for RuntimeLifecycleStackInfo
Sourcefn clone(&self) -> RuntimeLifecycleStackInfo
fn clone(&self) -> RuntimeLifecycleStackInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeLifecycleStackInfo
impl Debug for RuntimeLifecycleStackInfo
Sourceimpl<__Context> Decode<__Context> for RuntimeLifecycleStackInfo
impl<__Context> Decode<__Context> for RuntimeLifecycleStackInfo
Sourcefn decode<__D>(
decoder: &mut __D,
) -> Result<RuntimeLifecycleStackInfo, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(
decoder: &mut __D,
) -> Result<RuntimeLifecycleStackInfo, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
Sourceimpl Encode for RuntimeLifecycleStackInfo
impl Encode for RuntimeLifecycleStackInfo
impl Eq for RuntimeLifecycleStackInfo
impl StructuralPartialEq for RuntimeLifecycleStackInfo