Enum Tov
pub enum Tov {
None,
Time(CuDuration),
Range(CuTimeRange),
}Expand description
The time of validity of a message can be more than one time but can be a time range of Tovs. For example a sub scan for a lidar, a set of images etc… can have a range of validity.
Variants