Function finish_observed_encode
pub fn finish_observed_encode() -> usizeExpand description
Ends observed byte counting and returns the total bytes written.
pub fn finish_observed_encode() -> usizeEnds observed byte counting and returns the total bytes written.