Function structured_log_bytes_total
pub fn structured_log_bytes_total() -> u64Expand description
Returns the total number of bytes written to the structured log stream.
pub fn structured_log_bytes_total() -> u64Returns the total number of bytes written to the structured log stream.