pub struct NoopSectionStorage { /* private fields */ }Trait Implementations
Sourceimpl Debug for NoopSectionStorage
impl Debug for NoopSectionStorage
Sourceimpl Default for NoopSectionStorage
impl Default for NoopSectionStorage
Sourcefn default() -> NoopSectionStorage
fn default() -> NoopSectionStorage
Returns the “default value” for a type. Read more
Sourceimpl SectionStorage for NoopSectionStorage
impl SectionStorage for NoopSectionStorage
Sourcefn initialize<E>(&mut self, header: &E) -> Result<usize, EncodeError>where
E: Encode,
fn initialize<E>(&mut self, header: &E) -> Result<usize, EncodeError>where
E: Encode,
This rewinds the storage, serialize the header and jumps to the beginning of the user data storage.
Sourcefn post_update_header<E>(&mut self, header: &E) -> Result<usize, EncodeError>where
E: Encode,
fn post_update_header<E>(&mut self, header: &E) -> Result<usize, EncodeError>where
E: Encode,
This updates the header leaving the position to the end of the user data storage.
Sourceimpl UnifiedLogWrite<NoopSectionStorage> for NoopLogger
impl UnifiedLogWrite<NoopSectionStorage> for NoopLogger
Sourcefn add_section(
&mut self,
entry_type: UnifiedLogType,
requested_section_size: usize,
) -> Result<SectionHandle<NoopSectionStorage>, CuError>
fn add_section( &mut self, entry_type: UnifiedLogType, requested_section_size: usize, ) -> Result<SectionHandle<NoopSectionStorage>, CuError>
A section is a contiguous chunk of memory that can be used to write data.
It can store various types of data as specified by the entry_type.
The requested_section_size is the size of the section to allocate.
It returns a handle to the section that can be used to write data until
it is flushed with flush_section, it is then considered unmutable.
Sourcefn flush_section(&mut self, section: &mut SectionHandle<NoopSectionStorage>)
fn flush_section(&mut self, section: &mut SectionHandle<NoopSectionStorage>)
Flush the given section to the underlying storage.
Sourcefn status(&self) -> UnifiedLogStatus
fn status(&self) -> UnifiedLogStatus
Returns the current status of the unified logger.