CuArray

Struct CuArray 

pub struct CuArray<T, const N: usize>
where T: Clone,
{ /* private fields */ }
Copper friendly wrapper for a fixed size array. T: Clone is required because this type derives Reflect, and the reflection path requires the reflected value to be cloneable.

Implementations

Source

impl<T, const N: usize> CuArray<T, N>
where T: Clone,

pub fn new() -> CuArray<T, N>

pub fn fill_from_iter<I>(&mut self, iter: I)
where I: IntoIterator<Item = T>,

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn as_slice(&self) -> &[T]

pub fn capacity(&self) -> usize