pub struct CuHandle<T>(/* private fields */)
where
T: Debug + Send + Sync;Expand description
A shareable handle to a pooled or detached object.
When T: ArrayLike, the handle also participates in Copper’s buffer pool APIs.
Implementations
Sourceimpl<T> CuHandle<T>
impl<T> CuHandle<T>
Sourcepub fn new_detached(inner: T) -> CuHandle<T>
pub fn new_detached(inner: T) -> CuHandle<T>
Create a new CuHandle not part of a Pool (not for onboard usages, use pools instead)
Sourcepub fn new_detached_box(inner: Box<T>) -> CuHandle<T>
pub fn new_detached_box(inner: Box<T>) -> CuHandle<T>
Create a detached handle from an already heap-allocated object.
Sourcepub fn with_inner<R>(&self, f: impl FnOnce(&CuHandleInner<T>) -> R) -> R
pub fn with_inner<R>(&self, f: impl FnOnce(&CuHandleInner<T>) -> R) -> R
Safely access the inner value, applying a closure to it.
Sourcepub fn with_inner_mut<R>(&self, f: impl FnOnce(&mut CuHandleInner<T>) -> R) -> R
pub fn with_inner_mut<R>(&self, f: impl FnOnce(&mut CuHandleInner<T>) -> R) -> R
Mutably access the inner value, applying a closure to it.