GenericInfo

Enum GenericInfo 

pub enum GenericInfo {
    Type(TypeParamInfo),
    Const(ConstParamInfo),
}
An enum representing a generic parameter.

Variants



Type(TypeParamInfo)

A type parameter.

An example would be T in struct Foo<T, U>.



Const(ConstParamInfo)

A const parameter.

An example would be N in struct Foo<const N: usize>.

Implementations



impl GenericInfo

pub fn name(&self) -> &Cow<'static, str>

The name of the generic parameter.

pub fn is_const(&self) -> bool

Whether the generic parameter is a const parameter.

pub fn ty(&self) -> &Type

The underlying Rust type.

pub fn type_id(&self) -> TypeId

The TypeId of this type.

pub fn type_path(&self) -> &'static str

The stable, full type path of this type.

Use type_path_table if you need access to the other methods on TypePath.

pub fn type_path_table(&self) -> &TypePathTable

A representation of the type path of this type.

Provides dynamic access to all methods on TypePath.

pub fn is<T>(&self) -> bool
where T: Any,

Check if the given type matches this one.

This only compares the TypeId of the types and does not verify they share the same TypePath (though it implies they do).