ReflectKind

Enum ReflectKind 

pub enum ReflectKind {
    Struct,
    TupleStruct,
    Tuple,
    List,
    Array,
    Map,
    Set,
    Enum,
    Opaque,
}
An enumeration of the “kinds” of a reflected type.

Each kind corresponds to a specific reflection trait, such as Struct or List, which itself corresponds to the kind or structure of a type.

A ReflectKind is obtained via PartialReflect::reflect_kind, or via ReflectRef::kind,ReflectMut::kind or ReflectOwned::kind.

Variants



Struct

A struct-like type.



TupleStruct



Tuple

A tuple-like type.



List

A list-like type.



Array

An array-like type.



Map

A map-like type.



Set

A set-like type.



Enum

An enum-like type.



Opaque

An opaque type.

This most often represents a type where it is either impossible, difficult, or unuseful to reflect the type further.

This includes types like String and Instant.

Despite not technically being opaque types, primitives like u32 i32 are considered opaque for the purposes of reflection.

Additionally, any type that derives Reflect with the #[reflect(opaque)] attribute will be considered an opaque type.