Struct DynamicTuple
pub struct DynamicTuple { /* private fields */ }Expand description
A tuple which allows fields to be added at runtime.
Implementations
impl DynamicTuple
impl DynamicTuple
pub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicTuple.
Panics
Panics if the given type is not a TypeInfo::Tuple.
pub fn insert_boxed(&mut self, value: Box<dyn PartialReflect>)
pub fn insert_boxed(&mut self, value: Box<dyn PartialReflect>)
Appends an element with value value to the tuple.
pub fn insert<T>(&mut self, value: T)where
T: PartialReflect,
pub fn insert<T>(&mut self, value: T)where
T: PartialReflect,
Appends a typed element with value value to the tuple.