pub struct ResourceManager { /* private fields */ }Expand description
Manages the concrete resources available to tasks and bridges.
Implementations
Sourceimpl ResourceManager
impl ResourceManager
Sourcepub fn new(bundle_sizes: &[usize]) -> ResourceManager
pub fn new(bundle_sizes: &[usize]) -> ResourceManager
Creates a new manager sized for the number of resources generated for each bundle in the current mission.
Sourcepub fn add_owned<T>(
&mut self,
key: ResourceKey<T>,
value: T,
) -> Result<(), CuError>
pub fn add_owned<T>( &mut self, key: ResourceKey<T>, value: T, ) -> Result<(), CuError>
Register an owned resource in the slot identified by key.
Register a shared (borrowed) resource. Callers keep an Arc while tasks
receive references.
Sourcepub fn borrow<'r, T>(
&'r self,
key: ResourceKey<T>,
) -> Result<Borrowed<'r, T>, CuError>
pub fn borrow<'r, T>( &'r self, key: ResourceKey<T>, ) -> Result<Borrowed<'r, T>, CuError>
Borrow a shared resource by key.
Borrow a shared Arc-backed resource by key, cloning the Arc for the caller.
Sourcepub fn take<T>(&mut self, key: ResourceKey<T>) -> Result<Owned<T>, CuError>
pub fn take<T>(&mut self, key: ResourceKey<T>) -> Result<Owned<T>, CuError>
Take ownership of a resource by key.
Sourcepub fn add_bundle_prebuilt(
&mut self,
builder: impl FnOnce(&mut ResourceManager) -> Result<(), CuError>,
) -> Result<(), CuError>
pub fn add_bundle_prebuilt( &mut self, builder: impl FnOnce(&mut ResourceManager) -> Result<(), CuError>, ) -> Result<(), CuError>
Insert a prebuilt bundle by running a caller-supplied function. This is the escape hatch for resources that must be constructed in application code (for example, owning handles to embedded peripherals).