Struct CuMsgOrigin
pub struct CuMsgOrigin {
pub subsystem_code: u16,
pub instance_id: u32,
pub cl_id: u64,
}Expand description
Origin metadata captured when a Copper-aware transport receives a remote message.
Fields
subsystem_code: u16instance_id: u32cl_id: u64Trait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for CuMsgOrigin
impl<'__de, __Context> BorrowDecode<'__de, __Context> for CuMsgOrigin
fn borrow_decode<__D>(decoder: &mut __D) -> Result<CuMsgOrigin, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(decoder: &mut __D) -> Result<CuMsgOrigin, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for CuMsgOrigin
impl Clone for CuMsgOrigin
fn clone(&self) -> CuMsgOrigin
fn clone(&self) -> CuMsgOrigin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CuMsgOrigin
impl Debug for CuMsgOrigin
impl<__Context> Decode<__Context> for CuMsgOrigin
impl<__Context> Decode<__Context> for CuMsgOrigin
fn decode<__D>(decoder: &mut __D) -> Result<CuMsgOrigin, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<CuMsgOrigin, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl<'de> Deserialize<'de> for CuMsgOrigin
impl<'de> Deserialize<'de> for CuMsgOrigin
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CuMsgOrigin, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CuMsgOrigin, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Encode for CuMsgOrigin
impl Encode for CuMsgOrigin
impl FromReflect for CuMsgOrigin
impl FromReflect for CuMsgOrigin
fn from_reflect(reflect: &(dyn PartialReflect + 'static)) -> Option<CuMsgOrigin>
fn from_reflect(reflect: &(dyn PartialReflect + 'static)) -> Option<CuMsgOrigin>
Constructs a concrete instance of
Self from a reflected value.fn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreimpl GetTypeRegistration for CuMsgOrigin
impl GetTypeRegistration for CuMsgOrigin
fn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
Returns the default
TypeRegistration for this type.fn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers other types needed by this type. Read more
impl PartialEq for CuMsgOrigin
impl PartialEq for CuMsgOrigin
impl PartialReflect for CuMsgOrigin
impl PartialReflect for CuMsgOrigin
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn try_apply(
&mut self,
value: &(dyn PartialReflect + 'static),
) -> Result<(), ApplyError>
fn try_apply( &mut self, value: &(dyn PartialReflect + 'static), ) -> Result<(), ApplyError>
fn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Returns a zero-sized enumeration of “kinds” of type. Read more
fn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an immutable enumeration of “kinds” of type. Read more
fn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
fn reflect_owned(self: Box<CuMsgOrigin>) -> ReflectOwned
fn reflect_owned(self: Box<CuMsgOrigin>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
fn try_into_reflect(
self: Box<CuMsgOrigin>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<CuMsgOrigin>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Attempts to cast this type to a boxed, fully-reflected value.
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
Attempts to cast this type to a fully-reflected value.
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
Attempts to cast this type to a mutable, fully-reflected value.
fn into_partial_reflect(self: Box<CuMsgOrigin>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<CuMsgOrigin>) -> Box<dyn PartialReflect>
Casts this type to a boxed, reflected value. Read more
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
Casts this type to a reflected value. Read more
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
Casts this type to a mutable, reflected value. Read more
fn reflect_partial_eq(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Returns a “partial equality” comparison result. Read more
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Attempts to clone
Self using reflection. Read morefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Applies a reflected value to this value. Read more
fn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
For a type implementing
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails. Read morefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
fn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
impl Reflect for CuMsgOrigin
impl Reflect for CuMsgOrigin
fn into_any(self: Box<CuMsgOrigin>) -> Box<dyn Any>
fn into_any(self: Box<CuMsgOrigin>) -> Box<dyn Any>
Returns the value as a
Box<dyn Any>. Read morefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
Returns the value as a
&mut dyn Any. Read morefn into_reflect(self: Box<CuMsgOrigin>) -> Box<dyn Reflect>
fn into_reflect(self: Box<CuMsgOrigin>) -> Box<dyn Reflect>
Casts this type to a boxed, fully-reflected value.
fn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Casts this type to a fully-reflected value.
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Casts this type to a mutable, fully-reflected value.
impl Serialize for CuMsgOrigin
impl Serialize for CuMsgOrigin
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Struct for CuMsgOrigin
impl Struct for CuMsgOrigin
fn field(&self, name: &str) -> Option<&(dyn PartialReflect + 'static)>
fn field(&self, name: &str) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field named
name as a &dyn PartialReflect.fn field_mut(
&mut self,
name: &str,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_mut( &mut self, name: &str, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field named
name as a
&mut dyn PartialReflect.fn field_at(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
fn field_at(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field with index
index as a
&dyn PartialReflect.fn field_at_mut(
&mut self,
index: usize,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_at_mut( &mut self, index: usize, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field with index
index
as a &mut dyn PartialReflect.fn iter_fields(&self) -> FieldIter<'_> ⓘ
fn iter_fields(&self) -> FieldIter<'_> ⓘ
Returns an iterator over the values of the reflectable fields for this struct.
fn to_dynamic_struct(&self) -> DynamicStruct
fn to_dynamic_struct(&self) -> DynamicStruct
Creates a new
DynamicStruct from this struct.fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
Will return
None if TypeInfo is not available.impl TypePath for CuMsgOrigin
impl TypePath for CuMsgOrigin
fn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
fn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
impl Typed for CuMsgOrigin
impl Typed for CuMsgOrigin
impl Eq for CuMsgOrigin
impl StructuralPartialEq for CuMsgOrigin