Struct EndOfLogMarker
pub struct EndOfLogMarker {
pub temporary: bool,
}Expand description
Payload stored in the end-of-log section to signal whether the log was cleanly closed.
Fields
temporary: boolTrait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for EndOfLogMarker
impl<'__de, __Context> BorrowDecode<'__de, __Context> for EndOfLogMarker
fn borrow_decode<__D>(decoder: &mut __D) -> Result<EndOfLogMarker, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(decoder: &mut __D) -> Result<EndOfLogMarker, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for EndOfLogMarker
impl Clone for EndOfLogMarker
fn clone(&self) -> EndOfLogMarker
fn clone(&self) -> EndOfLogMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for EndOfLogMarker
impl Debug for EndOfLogMarker
impl<__Context> Decode<__Context> for EndOfLogMarker
impl<__Context> Decode<__Context> for EndOfLogMarker
fn decode<__D>(decoder: &mut __D) -> Result<EndOfLogMarker, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<EndOfLogMarker, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl Encode for EndOfLogMarker
impl Encode for EndOfLogMarker