Struct LoggerRuntime
pub struct LoggerRuntime {}Expand description
The lifetime of this struct is the lifetime of the logger.
Implementations
impl LoggerRuntime
impl LoggerRuntime
pub fn init(
clock: RobotClock,
destination: impl WriteStream<CuLogEntry> + 'static,
extra_text_logger: Option<impl Log + 'static>,
) -> LoggerRuntime
pub fn init( clock: RobotClock, destination: impl WriteStream<CuLogEntry> + 'static, extra_text_logger: Option<impl Log + 'static>, ) -> LoggerRuntime
destination is the binary stream in which we will log the structured log.
extra_text_logger is the logger that will log the text logs in real time. This is slow and only for debug builds.
pub fn flush(&self)