Struct MainHeader
pub struct MainHeader {
pub magic: [u8; 4],
pub first_section_offset: u16,
pub page_size: u16,
}Expand description
The main file header of the datalogger.
Fields
magic: [u8; 4]first_section_offset: u16page_size: u16Trait Implementations
impl<'__de, __Context> BorrowDecode<'__de, __Context> for MainHeader
impl<'__de, __Context> BorrowDecode<'__de, __Context> for MainHeader
fn borrow_decode<__D>(decoder: &mut __D) -> Result<MainHeader, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
fn borrow_decode<__D>(decoder: &mut __D) -> Result<MainHeader, DecodeError>where
__D: BorrowDecoder<'__de, Context = __Context>,
Attempt to decode this type with the given BorrowDecode.
impl Debug for MainHeader
impl Debug for MainHeader
impl<__Context> Decode<__Context> for MainHeader
impl<__Context> Decode<__Context> for MainHeader
fn decode<__D>(decoder: &mut __D) -> Result<MainHeader, DecodeError>where
__D: Decoder<Context = __Context>,
fn decode<__D>(decoder: &mut __D) -> Result<MainHeader, DecodeError>where
__D: Decoder<Context = __Context>,
Attempt to decode this type with the given Decode.
impl Display for MainHeader
impl Display for MainHeader
impl Encode for MainHeader
impl Encode for MainHeader