ClockProvider

Trait ClockProvider 

pub trait ClockProvider {
    // Required method
    fn get_clock(&self) -> RobotClock;
}
A trait to provide a clock to the runtime.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<CT, CB, P, M, const NBCL: usize> ClockProvider for CuRuntime<CT, CB, P, M, NBCL>
where P: CopperListTuple + CuListZeroedInit + Default + AsyncCopperListPayload, M: CuMonitor,

To be able to share the clock we make the runtime a clock provider.