ReflectConvert

Struct ReflectConvert 

pub struct ReflectConvert { /* private fields */ }
Provides a mechanism for converting values of one type to another.

This crate::type_registry::TypeData is associated with the type to be converted into, not the type to be converted from. To convert a value, use code like the following:


let reflect_convert = registry
    .get_type_data::<ReflectConvert>(TypeId::of::<String>())
    .unwrap();
let converted: String = *reflect_convert
    .try_convert_from(Box::new(12345i32))
    .unwrap()
    .downcast::<String>()
    .unwrap();

Implementations



impl ReflectConvert

pub fn try_convert_from( &self, input: Box<dyn Reflect>, ) -> Result<Box<dyn Reflect>, Box<dyn Reflect>>

Attempts to construct an instance of this type from the provided input.

If the conversion fails, either because no conversion has been registered from the type of input or because the conversion function itself returned Err, the input value is returned as an error.

pub fn register_type_conversion<T, U, F>(&mut self, function: F)
where T: Reflect + TypePath, U: Reflect + TypePath, F: Fn(T) -> Result<U, T> + Clone + Send + Sync + 'static,

Adds a conversion function from the type T to this type.

If the conversion succeeds, the function should return the converted value. If the conversion fails, the function should return the original input value.