Enum VariantField
pub enum VariantField<'a> {
Struct(&'a str, &'a (dyn PartialReflect + 'static)),
Tuple(&'a (dyn PartialReflect + 'static)),
}Expand description
A field in the current enum variant.
Variants
Struct(&'a str, &'a (dyn PartialReflect + 'static))
The name and value of a field in a struct variant.
Tuple(&'a (dyn PartialReflect + 'static))
The value of a field in a tuple variant.
Implementations
impl<'a> VariantField<'a>
impl<'a> VariantField<'a>