Typed

Trait Typed 

pub trait Typed: Reflect + TypePath {
    // Required method
    fn type_info() -> &'static TypeInfo;
}
A static accessor to compile-time type information.

This trait is automatically implemented by the #[derive(Reflect)] macro and allows type information to be processed without an instance of that type.

If you need to use this trait as a generic bound along with other reflection traits, for your convenience, consider using Reflectable instead.

Implementing

While it is recommended to leave implementing this trait to the #[derive(Reflect)] macro, it is possible to implement this trait manually. If a manual implementation is needed, you must ensure that the information you provide is correct, otherwise various systems that rely on this trait may fail in unexpected ways.

Implementors may have difficulty in generating a reference to TypeInfo with a static lifetime. Luckily, this crate comes with some utility structs, to make generating these statics much simpler.

Example

use bevy_reflect::Typed;

struct MyStruct {
  foo: usize,
  bar: (f32, f32)
}

impl Typed for MyStruct {
  fn type_info() -> &'static TypeInfo {
    static CELL: NonGenericTypeInfoCell = NonGenericTypeInfoCell::new();
    CELL.get_or_set(|| {
      let fields = [
        NamedField::new::<usize >("foo"),
        NamedField::new::<(f32, f32) >("bar"),
      ];
      let info = StructInfo::new::<Self>(&fields);
      TypeInfo::Struct(info)
    })
  }
}

Required Methods

fn type_info() -> &'static TypeInfo

Returns the compile-time info for the underlying type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl Typed for &'static str



fn type_info() -> &'static TypeInfo



impl Typed for &'static Location<'static>



fn type_info() -> &'static TypeInfo



impl Typed for Cow<'static, str>



fn type_info() -> &'static TypeInfo



impl Typed for SocketAddr



fn type_info() -> &'static TypeInfo



impl Typed for bool



fn type_info() -> &'static TypeInfo



impl Typed for char



fn type_info() -> &'static TypeInfo



impl Typed for f32



fn type_info() -> &'static TypeInfo



impl Typed for f64



fn type_info() -> &'static TypeInfo



impl Typed for i8



fn type_info() -> &'static TypeInfo



impl Typed for i16



fn type_info() -> &'static TypeInfo



impl Typed for i32



fn type_info() -> &'static TypeInfo



impl Typed for i64



fn type_info() -> &'static TypeInfo



impl Typed for i128



fn type_info() -> &'static TypeInfo



impl Typed for isize



fn type_info() -> &'static TypeInfo



impl Typed for u8



fn type_info() -> &'static TypeInfo



impl Typed for u16



fn type_info() -> &'static TypeInfo



impl Typed for u32



fn type_info() -> &'static TypeInfo



impl Typed for u64



fn type_info() -> &'static TypeInfo



impl Typed for u128



fn type_info() -> &'static TypeInfo



impl Typed for ()



fn type_info() -> &'static TypeInfo



impl Typed for usize



fn type_info() -> &'static TypeInfo



impl Typed for String



fn type_info() -> &'static TypeInfo



impl Typed for TypeId



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<i8>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<i16>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<i32>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<i64>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<i128>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<isize>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<u8>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<u16>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<u32>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<u64>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<u128>



fn type_info() -> &'static TypeInfo



impl Typed for NonZero<usize>



fn type_info() -> &'static TypeInfo



impl Typed for RangeFull



fn type_info() -> &'static TypeInfo



impl Typed for AtomicBool



fn type_info() -> &'static TypeInfo



impl Typed for AtomicI8



fn type_info() -> &'static TypeInfo



impl Typed for AtomicI16



fn type_info() -> &'static TypeInfo



impl Typed for AtomicI32



fn type_info() -> &'static TypeInfo



impl Typed for AtomicI64



fn type_info() -> &'static TypeInfo



impl Typed for AtomicIsize



fn type_info() -> &'static TypeInfo



impl Typed for AtomicU8



fn type_info() -> &'static TypeInfo



impl Typed for AtomicU16



fn type_info() -> &'static TypeInfo



impl Typed for AtomicU32



fn type_info() -> &'static TypeInfo



impl Typed for AtomicU64



fn type_info() -> &'static TypeInfo



impl Typed for AtomicUsize



fn type_info() -> &'static TypeInfo



impl Typed for Duration



fn type_info() -> &'static TypeInfo



impl Typed for Absement



fn type_info() -> &'static TypeInfo



impl Typed for Absement



fn type_info() -> &'static TypeInfo



impl Typed for Acceleration



fn type_info() -> &'static TypeInfo



impl Typed for Acceleration



fn type_info() -> &'static TypeInfo



impl Typed for Action



fn type_info() -> &'static TypeInfo



impl Typed for Action



fn type_info() -> &'static TypeInfo



impl Typed for AmountOfSubstance



fn type_info() -> &'static TypeInfo



impl Typed for AmountOfSubstance



fn type_info() -> &'static TypeInfo



impl Typed for Angle



fn type_info() -> &'static TypeInfo



impl Typed for Angle



fn type_info() -> &'static TypeInfo



impl Typed for AngularAbsement



fn type_info() -> &'static TypeInfo



impl Typed for AngularAbsement



fn type_info() -> &'static TypeInfo



impl Typed for AngularAcceleration



fn type_info() -> &'static TypeInfo



impl Typed for AngularAcceleration



fn type_info() -> &'static TypeInfo



impl Typed for AngularJerk



fn type_info() -> &'static TypeInfo



impl Typed for AngularJerk



fn type_info() -> &'static TypeInfo



impl Typed for AngularMomentum



fn type_info() -> &'static TypeInfo



impl Typed for AngularMomentum



fn type_info() -> &'static TypeInfo



impl Typed for AngularVelocity



fn type_info() -> &'static TypeInfo



impl Typed for AngularVelocity



fn type_info() -> &'static TypeInfo



impl Typed for Area



fn type_info() -> &'static TypeInfo



impl Typed for Area



fn type_info() -> &'static TypeInfo



impl Typed for ArealDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for ArealDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for ArealHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for ArealHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for ArealMassDensity



fn type_info() -> &'static TypeInfo



impl Typed for ArealMassDensity



fn type_info() -> &'static TypeInfo



impl Typed for ArealNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for ArealNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for ArealNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for ArealNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for AvailableEnergy



fn type_info() -> &'static TypeInfo



impl Typed for AvailableEnergy



fn type_info() -> &'static TypeInfo



impl Typed for Capacitance



fn type_info() -> &'static TypeInfo



impl Typed for Capacitance



fn type_info() -> &'static TypeInfo



impl Typed for CatalyticActivity



fn type_info() -> &'static TypeInfo



impl Typed for CatalyticActivity



fn type_info() -> &'static TypeInfo



impl Typed for CatalyticActivityConcentration



fn type_info() -> &'static TypeInfo



impl Typed for CatalyticActivityConcentration



fn type_info() -> &'static TypeInfo



impl Typed for Curvature



fn type_info() -> &'static TypeInfo



impl Typed for Curvature



fn type_info() -> &'static TypeInfo



impl Typed for DiffusionCoefficient



fn type_info() -> &'static TypeInfo



impl Typed for DiffusionCoefficient



fn type_info() -> &'static TypeInfo



impl Typed for DynamicViscosity



fn type_info() -> &'static TypeInfo



impl Typed for DynamicViscosity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCharge



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCharge



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeArealDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeArealDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeLinearDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeLinearDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeVolumetricDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricChargeVolumetricDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCurrent



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCurrent



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCurrentDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricCurrentDensity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricDipoleMoment



fn type_info() -> &'static TypeInfo



impl Typed for ElectricDipoleMoment



fn type_info() -> &'static TypeInfo



impl Typed for ElectricDisplacementField



fn type_info() -> &'static TypeInfo



impl Typed for ElectricDisplacementField



fn type_info() -> &'static TypeInfo



impl Typed for ElectricField



fn type_info() -> &'static TypeInfo



impl Typed for ElectricField



fn type_info() -> &'static TypeInfo



impl Typed for ElectricFlux



fn type_info() -> &'static TypeInfo



impl Typed for ElectricFlux



fn type_info() -> &'static TypeInfo



impl Typed for ElectricPermittivity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricPermittivity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricPotential



fn type_info() -> &'static TypeInfo



impl Typed for ElectricPotential



fn type_info() -> &'static TypeInfo



impl Typed for ElectricQuadrupoleMoment



fn type_info() -> &'static TypeInfo



impl Typed for ElectricQuadrupoleMoment



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalConductance



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalConductance



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalConductivity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalConductivity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalMobility



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalMobility



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalResistance



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalResistance



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalResistivity



fn type_info() -> &'static TypeInfo



impl Typed for ElectricalResistivity



fn type_info() -> &'static TypeInfo



impl Typed for Energy



fn type_info() -> &'static TypeInfo



impl Typed for Energy



fn type_info() -> &'static TypeInfo



impl Typed for Force



fn type_info() -> &'static TypeInfo



impl Typed for Force



fn type_info() -> &'static TypeInfo



impl Typed for Frequency



fn type_info() -> &'static TypeInfo



impl Typed for Frequency



fn type_info() -> &'static TypeInfo



impl Typed for FrequencyDrift



fn type_info() -> &'static TypeInfo



impl Typed for FrequencyDrift



fn type_info() -> &'static TypeInfo



impl Typed for HeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for HeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for HeatFluxDensity



fn type_info() -> &'static TypeInfo



impl Typed for HeatFluxDensity



fn type_info() -> &'static TypeInfo



impl Typed for HeatTransfer



fn type_info() -> &'static TypeInfo



impl Typed for HeatTransfer



fn type_info() -> &'static TypeInfo



impl Typed for Inductance



fn type_info() -> &'static TypeInfo



impl Typed for Inductance



fn type_info() -> &'static TypeInfo



impl Typed for Information



fn type_info() -> &'static TypeInfo



impl Typed for Information



fn type_info() -> &'static TypeInfo



impl Typed for InformationRate



fn type_info() -> &'static TypeInfo



impl Typed for InformationRate



fn type_info() -> &'static TypeInfo



impl Typed for Instant



fn type_info() -> &'static TypeInfo



impl Typed for InverseVelocity



fn type_info() -> &'static TypeInfo



impl Typed for InverseVelocity



fn type_info() -> &'static TypeInfo



impl Typed for Jerk



fn type_info() -> &'static TypeInfo



impl Typed for Jerk



fn type_info() -> &'static TypeInfo



impl Typed for KinematicViscosity



fn type_info() -> &'static TypeInfo



impl Typed for KinematicViscosity



fn type_info() -> &'static TypeInfo



impl Typed for Length



fn type_info() -> &'static TypeInfo



impl Typed for Length



fn type_info() -> &'static TypeInfo



impl Typed for LinearDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for LinearDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for LinearMassDensity



fn type_info() -> &'static TypeInfo



impl Typed for LinearMassDensity



fn type_info() -> &'static TypeInfo



impl Typed for LinearNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for LinearNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for LinearNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for LinearNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for LinearPowerDensity



fn type_info() -> &'static TypeInfo



impl Typed for LinearPowerDensity



fn type_info() -> &'static TypeInfo



impl Typed for Luminance



fn type_info() -> &'static TypeInfo



impl Typed for Luminance



fn type_info() -> &'static TypeInfo



impl Typed for LuminousIntensity



fn type_info() -> &'static TypeInfo



impl Typed for LuminousIntensity



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFieldStrength



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFieldStrength



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFlux



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFlux



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFluxDensity



fn type_info() -> &'static TypeInfo



impl Typed for MagneticFluxDensity



fn type_info() -> &'static TypeInfo



impl Typed for MagneticMoment



fn type_info() -> &'static TypeInfo



impl Typed for MagneticMoment



fn type_info() -> &'static TypeInfo



impl Typed for MagneticPermeability



fn type_info() -> &'static TypeInfo



impl Typed for MagneticPermeability



fn type_info() -> &'static TypeInfo



impl Typed for Mass



fn type_info() -> &'static TypeInfo



impl Typed for Mass



fn type_info() -> &'static TypeInfo



impl Typed for MassConcentration



fn type_info() -> &'static TypeInfo



impl Typed for MassConcentration



fn type_info() -> &'static TypeInfo



impl Typed for MassDensity



fn type_info() -> &'static TypeInfo



impl Typed for MassDensity



fn type_info() -> &'static TypeInfo



impl Typed for MassFlux



fn type_info() -> &'static TypeInfo



impl Typed for MassFlux



fn type_info() -> &'static TypeInfo



impl Typed for MassPerEnergy



fn type_info() -> &'static TypeInfo



impl Typed for MassPerEnergy



fn type_info() -> &'static TypeInfo



impl Typed for MassRate



fn type_info() -> &'static TypeInfo



impl Typed for MassRate



fn type_info() -> &'static TypeInfo



impl Typed for Molality



fn type_info() -> &'static TypeInfo



impl Typed for Molality



fn type_info() -> &'static TypeInfo



impl Typed for MolarConcentration



fn type_info() -> &'static TypeInfo



impl Typed for MolarConcentration



fn type_info() -> &'static TypeInfo



impl Typed for MolarEnergy



fn type_info() -> &'static TypeInfo



impl Typed for MolarEnergy



fn type_info() -> &'static TypeInfo



impl Typed for MolarFlux



fn type_info() -> &'static TypeInfo



impl Typed for MolarFlux



fn type_info() -> &'static TypeInfo



impl Typed for MolarHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for MolarHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for MolarMass



fn type_info() -> &'static TypeInfo



impl Typed for MolarMass



fn type_info() -> &'static TypeInfo



impl Typed for MolarRadioactivity



fn type_info() -> &'static TypeInfo



impl Typed for MolarRadioactivity



fn type_info() -> &'static TypeInfo



impl Typed for MolarVolume



fn type_info() -> &'static TypeInfo



impl Typed for MolarVolume



fn type_info() -> &'static TypeInfo



impl Typed for MomentOfInertia



fn type_info() -> &'static TypeInfo



impl Typed for MomentOfInertia



fn type_info() -> &'static TypeInfo



impl Typed for Momentum



fn type_info() -> &'static TypeInfo



impl Typed for Momentum



fn type_info() -> &'static TypeInfo



impl Typed for Power



fn type_info() -> &'static TypeInfo



impl Typed for Power



fn type_info() -> &'static TypeInfo



impl Typed for PowerRate



fn type_info() -> &'static TypeInfo



impl Typed for PowerRate



fn type_info() -> &'static TypeInfo



impl Typed for Pressure



fn type_info() -> &'static TypeInfo



impl Typed for Pressure



fn type_info() -> &'static TypeInfo



impl Typed for RadiantExposure



fn type_info() -> &'static TypeInfo



impl Typed for RadiantExposure



fn type_info() -> &'static TypeInfo



impl Typed for Radioactivity



fn type_info() -> &'static TypeInfo



impl Typed for Radioactivity



fn type_info() -> &'static TypeInfo



impl Typed for Ratio



fn type_info() -> &'static TypeInfo



impl Typed for Ratio



fn type_info() -> &'static TypeInfo



impl Typed for ReciprocalLength



fn type_info() -> &'static TypeInfo



impl Typed for ReciprocalLength



fn type_info() -> &'static TypeInfo



impl Typed for SolidAngle



fn type_info() -> &'static TypeInfo



impl Typed for SolidAngle



fn type_info() -> &'static TypeInfo



impl Typed for SpecificArea



fn type_info() -> &'static TypeInfo



impl Typed for SpecificArea



fn type_info() -> &'static TypeInfo



impl Typed for SpecificHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for SpecificHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for SpecificPower



fn type_info() -> &'static TypeInfo



impl Typed for SpecificPower



fn type_info() -> &'static TypeInfo



impl Typed for SpecificRadioactivity



fn type_info() -> &'static TypeInfo



impl Typed for SpecificRadioactivity



fn type_info() -> &'static TypeInfo



impl Typed for SpecificVolume



fn type_info() -> &'static TypeInfo



impl Typed for SpecificVolume



fn type_info() -> &'static TypeInfo



impl Typed for SurfaceElectricCurrentDensity



fn type_info() -> &'static TypeInfo



impl Typed for SurfaceElectricCurrentDensity



fn type_info() -> &'static TypeInfo



impl Typed for SurfaceTension



fn type_info() -> &'static TypeInfo



impl Typed for SurfaceTension



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureCoefficient



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureCoefficient



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureGradient



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureGradient



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureInterval



fn type_info() -> &'static TypeInfo



impl Typed for TemperatureInterval



fn type_info() -> &'static TypeInfo



impl Typed for ThermalConductance



fn type_info() -> &'static TypeInfo



impl Typed for ThermalConductance



fn type_info() -> &'static TypeInfo



impl Typed for ThermalConductivity



fn type_info() -> &'static TypeInfo



impl Typed for ThermalConductivity



fn type_info() -> &'static TypeInfo



impl Typed for ThermalResistance



fn type_info() -> &'static TypeInfo



impl Typed for ThermalResistance



fn type_info() -> &'static TypeInfo



impl Typed for ThermodynamicTemperature



fn type_info() -> &'static TypeInfo



impl Typed for ThermodynamicTemperature



fn type_info() -> &'static TypeInfo



impl Typed for Time



fn type_info() -> &'static TypeInfo



impl Typed for Time



fn type_info() -> &'static TypeInfo



impl Typed for Torque



fn type_info() -> &'static TypeInfo



impl Typed for Torque



fn type_info() -> &'static TypeInfo



impl Typed for Velocity



fn type_info() -> &'static TypeInfo



impl Typed for Velocity



fn type_info() -> &'static TypeInfo



impl Typed for Volume



fn type_info() -> &'static TypeInfo



impl Typed for Volume



fn type_info() -> &'static TypeInfo



impl Typed for VolumeRate



fn type_info() -> &'static TypeInfo



impl Typed for VolumeRate



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricDensityOfStates



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricHeatCapacity



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricNumberDensity



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricNumberRate



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricPowerDensity



fn type_info() -> &'static TypeInfo



impl Typed for VolumetricPowerDensity



fn type_info() -> &'static TypeInfo



impl<A> Typed for (A,)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B> Typed for (A, B)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C> Typed for (A, B, C)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D> Typed for (A, B, C, D)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E> Typed for (A, B, C, D, E)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F> Typed for (A, B, C, D, E, F)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G> Typed for (A, B, C, D, E, F, G)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G, H> Typed for (A, B, C, D, E, F, G, H)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G, H, I> Typed for (A, B, C, D, E, F, G, H, I)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G, H, I, J> Typed for (A, B, C, D, E, F, G, H, I, J)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G, H, I, J, K> Typed for (A, B, C, D, E, F, G, H, I, J, K)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration, K: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<A, B, C, D, E, F, G, H, I, J, K, L> Typed for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Reflect + MaybeTyped + TypePath + GetTypeRegistration, B: Reflect + MaybeTyped + TypePath + GetTypeRegistration, C: Reflect + MaybeTyped + TypePath + GetTypeRegistration, D: Reflect + MaybeTyped + TypePath + GetTypeRegistration, E: Reflect + MaybeTyped + TypePath + GetTypeRegistration, F: Reflect + MaybeTyped + TypePath + GetTypeRegistration, G: Reflect + MaybeTyped + TypePath + GetTypeRegistration, H: Reflect + MaybeTyped + TypePath + GetTypeRegistration, I: Reflect + MaybeTyped + TypePath + GetTypeRegistration, J: Reflect + MaybeTyped + TypePath + GetTypeRegistration, K: Reflect + MaybeTyped + TypePath + GetTypeRegistration, L: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<K, V> Typed for BTreeMap<K, V>
where K: FromReflect + MaybeTyped + TypePath + GetTypeRegistration + Eq + Ord, V: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<K, V, S> Typed for HashMap<K, V, S>



fn type_info() -> &'static TypeInfo



impl<T> Typed for Cow<'static, [T]>
where T: FromReflect + MaybeTyped + Clone + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Bound<T>
where T: Clone + Send + Sync + TypePath, Bound<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Option<T>
where Option<T>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection,



fn type_info() -> &'static TypeInfo



impl<T> Typed for BinaryHeap<T>
where T: Clone + TypePath, BinaryHeap<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for BTreeSet<T>
where T: Ord + Eq + Clone + Send + Sync + TypePath, BTreeSet<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for VecDeque<T>
where T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Arc<T>
where T: Send + Sync + TypePath + ?Sized, Arc<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Vec<T>
where T: FromReflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Saturating<T>
where T: Clone + Send + Sync + TypePath, Saturating<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Wrapping<T>
where T: Clone + Send + Sync + TypePath, Wrapping<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for Range<T>
where T: Clone + Send + Sync + TypePath, Range<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for RangeFrom<T>
where T: Clone + Send + Sync + TypePath, RangeFrom<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for RangeInclusive<T>
where T: Clone + Send + Sync + TypePath, RangeInclusive<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for RangeTo<T>
where T: Clone + Send + Sync + TypePath, RangeTo<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T> Typed for RangeToInclusive<T>
where T: Clone + Send + Sync + TypePath, RangeToInclusive<T>: Any + Send + Sync,



fn type_info() -> &'static TypeInfo



impl<T, E> Typed for Result<T, E>
where Result<T, E>: Any + Send + Sync, T: TypePath + FromReflect + MaybeTyped + RegisterForReflection, E: TypePath + FromReflect + MaybeTyped + RegisterForReflection,



fn type_info() -> &'static TypeInfo



impl<T, const N: usize> Typed for [T; N]
where T: Reflect + MaybeTyped + TypePath + GetTypeRegistration,



fn type_info() -> &'static TypeInfo



impl<V, S> Typed for HashSet<V, S>



fn type_info() -> &'static TypeInfo

Implementors



impl Typed for Tov



impl Typed for CuDuration



impl Typed for CuTimeRange



impl Typed for OptionCuTime



impl Typed for PartialCuTimeRange



impl Typed for dyn Reflect

Source

impl<I> Typed for CuSimSinkTask<I>
where CuSimSinkTask<I>: Any + Send + Sync,

Source

impl<T> Typed for CuSimSrcTask<T>
where CuSimSrcTask<T>: Any + Send + Sync,

Source

impl<T, O> Typed for CuAsyncTask<T, O>
where CuAsyncTask<T, O>: Any + Send + Sync, T: for<'m> CuTask<Output<'m> = CuStampedData<O, CuMsgMetadata>> + Send + 'static, O: CuMsgPayload + Send + 'static,

Source

impl<T, const N: usize> Typed for CuArray<T, N>
where T: Clone + TypePath, CuArray<T, N>: Any + Send + Sync,