pub struct CuError { /* private fields */ }Expand description
Common copper Error type.
This error type stores an optional cause as a boxed dynamic error, allowing for proper error chaining while maintaining Clone and Serialize/Deserialize support through custom implementations.
Implementations
Sourceimpl CuError
impl CuError
Sourcepub fn new(message_index: usize) -> CuError
pub fn new(message_index: usize) -> CuError
Creates a new CuError from an interned string index. Used by the cu_error! macro.
The index is stored as a placeholder string [interned:{index}].
Actual string resolution happens at logging time via the unified logger.
Sourcepub fn new_with_cause<E>(message: &str, cause: E) -> CuError
pub fn new_with_cause<E>(message: &str, cause: E) -> CuError
Creates a new CuError with a message and an underlying cause.
Example
use cu29_traits::CuError;
let io_err = std::io::Error::other("io error");
let err = CuError::new_with_cause("Failed to read file", io_err);Sourcepub fn add_cause(self, context: &str) -> CuError
pub fn add_cause(self, context: &str) -> CuError
Adds or replaces the cause with a context string.
This is useful for adding context to errors during propagation.
Example
use cu29_traits::CuError;
let err = CuError::from("base error").add_cause("additional context");Sourcepub fn with_cause<E>(self, cause: E) -> CuError
pub fn with_cause<E>(self, cause: E) -> CuError
Adds a cause error to this CuError (builder pattern).
Example
use cu29_traits::CuError;
let io_err = std::io::Error::other("io error");
let err = CuError::from("Operation failed").with_cause(io_err);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CuError
impl<'de> Deserialize<'de> for CuError
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<CuError, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<CuError, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Error for CuError
Available on crate feature std only.
impl Error for CuError
std only.Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
Sourceimpl From<ConfigError> for CuError
impl From<ConfigError> for CuError
Sourcefn from(err: ConfigError) -> CuError
fn from(err: ConfigError) -> CuError
Sourceimpl<S, L, A> From<LifecycleError<S, L, A>> for CuError
Allows ? in functions returning CuResult when the faulted application
does not need to be recovered.
impl<S, L, A> From<LifecycleError<S, L, A>> for CuError
Allows ? in functions returning CuResult when the faulted application
does not need to be recovered.
Sourcefn from(value: LifecycleError<S, L, A>) -> CuError
fn from(value: LifecycleError<S, L, A>) -> CuError
Sourceimpl<S, L, A> From<SimLifecycleError<S, L, A>> for CuError
Available on crate feature std only.Allows ? in functions returning CuResult when the faulted application
does not need to be recovered.
impl<S, L, A> From<SimLifecycleError<S, L, A>> for CuError
std only.Allows ? in functions returning CuResult when the faulted application
does not need to be recovered.
Sourcefn from(value: SimLifecycleError<S, L, A>) -> CuError
fn from(value: SimLifecycleError<S, L, A>) -> CuError
Sourceimpl Serialize for CuError
impl Serialize for CuError
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,