Trait CuMsgMetadataTrait
pub trait CuMsgMetadataTrait {
// Required methods
fn process_time(&self) -> PartialCuTimeRange;
fn status_txt(&self) -> &CuCompactString;
// Provided method
fn origin(&self) -> Option<&CuMsgOrigin> { ... }
}Expand description
Key metadata piece attached to every message in Copper.
Required Methods
fn process_time(&self) -> PartialCuTimeRange
fn process_time(&self) -> PartialCuTimeRange
The time range used for the processing of this message
fn status_txt(&self) -> &CuCompactString
fn status_txt(&self) -> &CuCompactString
Small status text for user UI to get the realtime state of task (max 24 chrs)
Provided Methods
fn origin(&self) -> Option<&CuMsgOrigin>
fn origin(&self) -> Option<&CuMsgOrigin>
Remote Copper provenance captured on receive.