pub struct CuArray<T, const N: usize>where
T: Clone,{ /* private fields */ }Expand description
Copper friendly wrapper for a fixed size array.
T: Clone is required because this type derives Reflect, and
the reflection path requires the reflected value to be cloneable.
Implementations