pub struct RobotClockMock(/* private fields */);Expand description
A mock clock that can be controlled by the user.
Implementations
Sourceimpl RobotClockMock
impl RobotClockMock
pub fn increment(&self, amount: CuDuration)
Sourcepub fn decrement(&self, amount: CuDuration)
pub fn decrement(&self, amount: CuDuration)
Decrements the time by the given amount. Be careful this breaks the monotonicity of the clock.