pub trait ClockProvider {
// Required method
fn get_clock(&self) -> RobotClock;
}Expand description
A trait to provide a clock to the runtime.
Required Methods
fn get_clock(&self) -> RobotClock
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<CT, CB, P, M, const NBCL: usize> ClockProvider for CuRuntime<CT, CB, P, M, NBCL>
To be able to share the clock we make the runtime a clock provider.